@@ -6,10 +6,7 @@
 #include <stdbool.h>
 #include <libspectre/spectre.h>
 #include <zathura/plugin-api.h>
-
-#if HAVE_CAIRO
 #include <cairo.h>
-#endif
 
 /**
  * Open a PostScript document
@@ -18,7 +15,7 @@
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-zathura_error_t ps_document_open(zathura_document_t* document);
+GIRARA_HIDDEN zathura_error_t ps_document_open(zathura_document_t* document);
 
 /**
  * Closes and frees the internal document structure
@@ -27,7 +24,7 @@ zathura_error_t ps_document_open(zathura_document_t* document);
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-zathura_error_t ps_document_free(zathura_document_t* document, SpectreDocument* spectre_document);
+GIRARA_HIDDEN zathura_error_t ps_document_free(zathura_document_t* document, void* spectre_document);
 
 /**
  * Saves the document to the given path
@@ -37,7 +34,7 @@ zathura_error_t ps_document_free(zathura_document_t* document, SpectreDocument*
  * @return ZATHURA_ERROR_OK when no error occurred, otherwise see
  *    zathura_error_t
  */
-zathura_error_t ps_document_save_as(zathura_document_t* document, SpectreDocument* spectre_document, const char* path);
+GIRARA_HIDDEN zathura_error_t ps_document_save_as(zathura_document_t* document, void* spectre_document, const char* path);
 
 /**
  * Returns a list of document information entries of the document
@@ -47,7 +44,7 @@ zathura_error_t ps_document_save_as(zathura_document_t* document, SpectreDocumen
  *   error occurred
  * @return List of information entries or NULL if an error occurred
  */
-girara_list_t* ps_document_get_information(zathura_document_t* document, SpectreDocument*
+GIRARA_HIDDEN girara_list_t* ps_document_get_information(zathura_document_t* document, void*
     spectre_document, zathura_error_t* error);
 
 /**
@@ -57,7 +54,7 @@ girara_list_t* ps_document_get_information(zathura_document_t* document, Spectre
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-zathura_error_t ps_page_init(zathura_page_t* page, SpectrePage* spectre_page);
+GIRARA_HIDDEN zathura_error_t ps_page_init(zathura_page_t* page);
 
 /**
  * Renders a page and returns a allocated image buffer which has to be freed
@@ -68,9 +65,8 @@ zathura_error_t ps_page_init(zathura_page_t* page, SpectrePage* spectre_page);
  *   error occurred
  * @return Image buffer or NULL if an error occurred
  */
-zathura_image_buffer_t* ps_page_render(zathura_page_t* page, SpectrePage* spectre_page, zathura_error_t* error);
+GIRARA_HIDDEN zathura_image_buffer_t* ps_page_render(zathura_page_t* page, void* spectre_page, zathura_error_t* error);
 
-#if HAVE_CAIRO
 /**
  * Renders a page onto a cairo object
  *
@@ -80,8 +76,7 @@ zathura_image_buffer_t* ps_page_render(zathura_page_t* page, SpectrePage* spectr
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-zathura_error_t ps_page_render_cairo(zathura_page_t* page, SpectrePage* spectre_page, cairo_t* cairo, bool printing);
-#endif
+GIRARA_HIDDEN zathura_error_t ps_page_render_cairo(zathura_page_t* page, void* spectre_page, cairo_t* cairo, bool printing);
 
 /**
  * Frees a PostScript page
@@ -90,6 +85,6 @@ zathura_error_t ps_page_render_cairo(zathura_page_t* page, SpectrePage* spectre_
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-zathura_error_t ps_page_clear(zathura_page_t* page, SpectrePage* spectre_page);
+GIRARA_HIDDEN zathura_error_t ps_page_clear(zathura_page_t* page, void* spectre_page);
 
 #endif // PS_H
